@@ -252,17 +252,12 @@ static void
 gdl_dock_object_finalize (GObject *g_object)
 {
     GdlDockObject *object;
-    
-    g_return_if_fail (g_object != NULL && GDL_IS_DOCK_OBJECT (g_object));
 
     object = GDL_DOCK_OBJECT (g_object);
 
     g_free (object->name);
-    object->name = NULL;
     g_free (object->long_name);
-    object->long_name = NULL;
     g_free (object->stock_id);
-    object->stock_id = NULL;
 
     G_OBJECT_CLASS (gdl_dock_object_parent_class)->finalize (g_object);
 }
@@ -674,7 +669,7 @@ gdl_dock_object_reorder (GdlDockObject    *object,
     g_return_val_if_fail (object != NULL && child != NULL, FALSE);
 
     if (GDL_DOCK_OBJECT_GET_CLASS (object)->reorder)
-            GDL_DOCK_OBJECT_GET_CLASS (object)->reorder (object, child, new_position, other_data);
+            return GDL_DOCK_OBJECT_GET_CLASS (object)->reorder (object, child, new_position, other_data);
     else
         return FALSE;
 }
@@ -727,7 +722,7 @@ gdl_dock_object_child_placement (GdlDockObject    *object,
         return FALSE;
     
     if (GDL_DOCK_OBJECT_GET_CLASS (object)->child_placement)
-        GDL_DOCK_OBJECT_GET_CLASS (object)->child_placement (object, child, placement);
+        return GDL_DOCK_OBJECT_GET_CLASS (object)->child_placement (object, child, placement);
     else
         return FALSE;
 }
